@@ -26,6 +26,23 @@ use Module::Load::Conditional   qw[check_install];
 
 CPANPLUS::Config
 
+=head1 SYNOPSIS
+
+    ### conf object via CPANPLUS::Backend;
+    $cb   = CPANPLUS::Backend->new;
+    $conf = $cb->configure_object;
+    
+    ### or as a standalone object
+    $conf = CPANPLUS::Configure->new;
+
+    ### values in 'conf' section
+    $verbose = $conf->get_conf( 'verbose' );    
+    $conf->set_conf( verbose => 1 );
+
+    ### values in 'program' section
+    $editor = $conf->get_program( 'editor' );
+    $conf->set_program( editor => '/bin/vi' );
+
 =head1 DESCRIPTION
 
 This module contains defaults and heuristics for configuration 
@@ -40,7 +57,7 @@ their meaning.
 =cut
 
 ### BAH! you can't have POD interleaved with a hash
-### declaration.. so declare every entry seperatedly :(
+### declaration.. so declare every entry separately :(
 my $Conf = {
     '_fetch' => {
         'blacklist' => [ 'ftp' ],
@@ -108,13 +125,13 @@ An example entry would like this:
             },
             {
                 'scheme' => 'ftp',
-                'path' => '/pub/CPAN/',
-                'host' => 'ftp.nl.uu.net'
+                'path' => '/',
+                'host' => 'cpan.hexten.net'
             },
             {
                 'scheme' => 'ftp',
-                'path' => '/pub/CPAN/',
-                'host' => 'cpan.valueclick.com'
+                'path' => '/CPAN/',
+                'host' => 'cpan.cpantesters.org'
             },
             {
                 'scheme' => 'ftp',
@@ -134,7 +151,7 @@ are run interactively or not. Defaults to 'true'.
 
 =item base
 
-The directory CPANPLUS keeps all it's build and state information in.
+The directory CPANPLUS keeps all its build and state information in.
 Defaults to ~/.cpanplus.
 
 =cut
@@ -208,7 +225,7 @@ Defaults to C<true>
 
 =cut
 
-        ### this addresses #32248 which requests a possibillity to
+        ### this addresses #32248 which requests a possibility to
         ### turn off custom sources
         $Conf->{'conf'}->{'enable_custom_sources'} = 1;
 
@@ -280,14 +297,14 @@ when invoked. Defaults to an empty string.
 
 =item md5
 
-A boolean indicating whether or not md5 checks should be done when
-an archive is fetched. Defaults to 'true' if you have C<Digest::MD5>
+A boolean indicating whether or not sha256 checks should be done when
+an archive is fetched. Defaults to 'true' if you have C<Digest::SHA>
 installed, 'false' otherwise.
 
 =cut
 
         $Conf->{'conf'}->{'md5'} = ( 
-                            check_install( module => 'Digest::MD5' ) ? 1 : 0 );
+                            check_install( module => 'Digest::SHA' ) ? 1 : 0 );
 
 =item no_update
 
@@ -323,11 +340,17 @@ C<.tar.gz> files)
 =item prefer_makefile
 
 A boolean indicating whether or not prefer a C<Makefile.PL> over a 
-C<Build.PL> file if both are present. Defaults to 'true'.
+C<Build.PL> file if both are present. Defaults to 'true', unless
+the perl version is at least 5.10.1 or appropriate versions of L<Module::Build>
+and L<CPANPLUS::Dist::Build> are available.
 
 =cut
 
-        $Conf->{'conf'}->{'prefer_makefile'} = 1;
+        $Conf->{'conf'}->{'prefer_makefile'} = 
+            ( $] >= 5.010001 or 
+              ( check_install( module => 'Module::Build', version => '0.32' ) and
+                check_install( module => INSTALLER_BUILD, version => '0.24' ) )
+              ? 0 : 1 );
 
 =item prereqs
 
@@ -470,7 +493,7 @@ set it to:
 =item editor
 
 A string holding the path to your editor of choice. Defaults to your
-$ENV{EDITOR}, $ENV{VISIUAL}, 'vi' or 'pico' programs, in that order.
+$ENV{EDITOR}, $ENV{VISUAL}, 'vi' or 'pico' programs, in that order.
 
 =cut
 
@@ -518,12 +541,11 @@ $ENV{SHELL} setting, or $ENV{COMSPEC} on Windows.
 
 A string holding the path to your C<sudo> binary if your install path
 requires super user permissions. Looks for C<sudo> in your path, or 
-remains empty if you do not require super user permissiosn to install.
+remains empty if you do not require super user permissions to install.
 
 =cut
 
         $Conf->{'program'}->{'sudo'} = do {
-
             ### let's assume you dont need sudo,
             ### unless one of the below criteria tells us otherwise
             my $sudo = undef;
@@ -532,17 +554,20 @@ remains empty if you do not require super user permissiosn to install.
             if( $> ) {
     
                 ### check for all install dirs!
-                ### installsiteman3dir is a 5.8'ism.. don't check
-                ### it on 5.6.x...            
                 ### you have write permissions to the installdir,
                 ### you don't need sudo
-                if( -w $Config{'installsitelib'} &&
-                    ( defined $Config{'installsiteman3dir'} && 
-                      -w $Config{'installsiteman3dir'} 
-                    ) && -w $Config{'installsitebin'} 
-                ) {                    
-                    $sudo = undef;
+                if( -w $Config{'installsitelib'} && -w $Config{'installsitebin'} ) {                    
                     
+                    ### installsiteman3dir is a 5.8'ism.. don't check
+                    ### it on 5.6.x...            
+                    if( defined $Config{'installsiteman3dir'} ) {
+                        $sudo = -w $Config{'installsiteman3dir'} 
+                            ? undef
+                            : can_run('sudo');
+                    } else {
+                        $sudo = undef;
+                    }
+
                 ### you have PERL_MM_OPT set to some alternate
                 ### install place. You probably have write permissions
                 ### to that
@@ -612,7 +637,7 @@ with CPANPLUS, which is used to enable autoflushing in spawned processes.
                 $path = $maybe and last BIN if -f $maybe;
                          
                 ### you installed CPANPLUS in a custom prefix,
-                ### so go paralel to /that/. PREFIX=/tmp/cp
+                ### so go parallel to /that/. PREFIX=/tmp/cp
                 ### would put cpanp-run-perl in /tmp/cp/bin and
                 ### CPANPLUS.pm in
                 ### /tmp/cp/lib/perl5/site_perl/5.8.8
