@@ -4,6 +4,7 @@ use strict;
 use Params::Check               qw[check];
 use IPC::Cmd                    qw[can_run];
 use CPANPLUS::Error             qw[error msg];
+use Module::Load::Conditional   qw[check_install];
 use Locale::Maketext::Simple    Class => 'CPANPLUS', Style => 'gettext';
 
 use CPANPLUS::Internals::Constants;
@@ -46,7 +47,7 @@ CPANPLUS::Selfupdate
             'Locale::Maketext::Simple'  => '0.01',
             'Log::Message'              => '0.01',
             'Module::Load'              => '0.10',
-            'Module::Load::Conditional' => '0.28', # returns dir for loaded
+            'Module::Load::Conditional' => '0.38', # returns dir for loaded
                                                    # modules
             'version'                   => '0.73', # needed for M::L::C
                                                    # addresses #24630 and 
@@ -62,11 +63,13 @@ CPANPLUS::Selfupdate
             'Archive::Tar'              => '1.23',
             'IO::Zlib'                  => '1.04', # needed for Archive::Tar
             'Object::Accessor'          => '0.34', # mk_aliases support
-            'Module::CoreList'          => '2.09',
+            'Module::CoreList'          => '2.22', # deprecated core modules
             'Module::Pluggable'         => '2.4',
             'Module::Loaded'            => '0.01',
-            'Parse::CPAN::Meta'         => '0.02', # config_requires support
+            'Parse::CPAN::Meta'         => '1.4200', # config_requires support
             'ExtUtils::Install'         => '1.42', # uninstall outside @INC
+            ( check_install( module => 'CPANPLUS::Dist::Build' ) 
+              ? ( 'CPANPLUS::Dist::Build' => '0.24' ) : () ),
         },
     
         features => {
@@ -79,13 +82,13 @@ CPANPLUS::Selfupdate
                     my $cb = shift;
                     $cb->configure_object->get_conf('prefer_makefile') 
                         ? { }
-                        : { 'CPANPLUS::Dist::Build' => '0.04'  };
+                        : { 'CPANPLUS::Dist::Build' => '0.24'  };
                 },
                 sub { return 1 },   # always enabled
             ],            
             cpantest        => [
                 { 'Test::Reporter'  => '1.34',
-                  'YAML::Tiny'      => '0.0'
+                  'Parse::CPAN::Meta' => '0.0'
                 },
                 sub { 
                     my $cb = shift;
@@ -107,7 +110,7 @@ CPANPLUS::Selfupdate
 
             md5 => [
                 {
-                    'Digest::MD5'   => '0.0',
+                    'Digest::SHA'   => '0.0',
                 },            
                 sub { 
                     my $cb = shift;
@@ -233,7 +236,7 @@ See C<selfupdate> for details.
     sub list_categories { return sort keys %$cache }
 
 =head2 %list = $self->list_modules_to_update( update => "core|dependencies|enabled_features|features|all", [latest => BOOL] )
-    
+
 List which modules C<selfupdate> would upgrade. You can update either 
 the core (CPANPLUS itself), the core dependencies, all features you have
 currently turned on, or all features available, or everything.
@@ -246,11 +249,11 @@ Returns a hash of feature names and lists of module objects to be
 upgraded based on the category you provided. For example:
 
     %list = $self->list_modules_to_update( update => 'core' );
-    
+
 Would return:
 
     ( core => [ $module_object_for_cpanplus ] );
-    
+
 =cut    
     
     sub list_modules_to_update {
@@ -287,7 +290,7 @@ Would return:
         
         return %list;
     }
-    
+
 =head2 $bool = $self->selfupdate( update => "core|dependencies|enabled_features|features|all", [latest => BOOL, force => BOOL] )
 
 Selfupdate CPANPLUS. You can update either the core (CPANPLUS itself),
