@@ -26,7 +26,7 @@ local $Data::Dumper::Indent     = 1; # for dumpering from !
 BEGIN {
     use vars        qw[ $VERSION @ISA ];
     @ISA        =   qw[ CPANPLUS::Shell::_Base::ReadLine ];
-    $VERSION = "0.89_12";
+    $VERSION = "0.90_12";
 }
 
 load CPANPLUS::Shell;
@@ -142,7 +142,7 @@ CPANPLUS::Shell::Default
 
     cpanp> q                 # quit the shell
 
-    cpanp> /plugins          # list avialable plugins
+    cpanp> /plugins          # list available plugins
     cpanp> /? PLUGIN         # list help test of <PLUGIN>                  
 
     ### common options:
@@ -1222,6 +1222,7 @@ sub _set_conf {
 
     my ($type,$key,$value) = $input =~ m/(\w+)\s*(\w*)\s*(.*?)$/;
     $value =~ s/\s+$//g if $value;
+    $type = '' unless defined $type;
     $type = lc $type;
 
     if( $type eq 'reconfigure' ) {
